@@ -118,7 +118,7 @@
 #define ALPHA_MIN    0.02
 #define ALPHA_MAX    1000.0
 
-#define RATE_MIN     0.0000001
+#define RATE_MIN     0.0001
 #define RATE_MAX     1000000.0
 
 #define INVAR_MIN    0.0001
@@ -168,9 +168,9 @@
 #define PointGamma(prob,alpha,beta)  PointChi2(prob,2.0*(alpha))/(2.0*(beta))
 
 #define programName        "RAxML"
-#define programVersion     "8.2.0"
-#define programVersionInt   8200
-#define programDate        "July 9 2015"
+#define programVersion     "8.2.4"
+#define programVersionInt   8240
+#define programDate        "October 02 2015"
 
 
 #define  TREE_EVALUATION                 0
@@ -604,7 +604,6 @@ typedef struct {
   boolean ascBias;  
   int     ascOffset;
   int     *ascExpVector;
-  int     *ascMissingVector;
   double  *ascSumBuffer;
   double  *ascVector;
   double ascScaler[64];
@@ -662,8 +661,6 @@ typedef struct {
   double weightsBuffer[4];
   double weightExponentsBuffer[4];
 
-  double weightLikelihood;
-
   /* LG4 */
 
   double *frequencies;
@@ -1068,9 +1065,7 @@ typedef  struct  {
     
   boolean doSubtreeEPA;
 
-  double ascMissing;
-  boolean useAscMissing;
-
+  
 } tree;
 
 
@@ -1210,7 +1205,9 @@ typedef struct
 
 /****************************** FUNCTIONS ****************************************************/
 
-extern void ascertainmentBiasSequence(unsigned char tip[32], int numStates, int dataType, int nodeNumber, int *ascMissingVector);
+
+
+extern void ascertainmentBiasSequence(unsigned char tip[32], int numStates, int dataType, int nodeNumber);
 
 extern void computePlacementBias(tree *tr, analdef *adef);
 
