@@ -64,7 +64,7 @@ extern char seq_file[1024];
 extern char permFileName[1024], resultFileName[1024], 
   logFileName[1024], checkpointFileName[1024], infoFileName[1024], run_id[128], workdir[1024], bootStrapFile[1024], bootstrapFileName[1024], 
   bipartitionsFileName[1024],bipartitionsFileNameBranchLabels[1024], rellBootstrapFileNamePID[1024], mesquiteTrees[1024],
-  mesquiteModel[1024];
+  mesquiteModel[1024], mesquiteMLTrees[1024], mesquiteMLLikes[1024];
 
 
 
@@ -260,125 +260,6 @@ void reductionCleanup(tree *tr, int *originalRateCategories, int *originalInvari
 
 
 
-/* old problematic code by Andre
-
-void computeNextReplicate(tree *tr, int64_t *randomSeed, int *originalRateCategories, int *originalInvariant, boolean isRapid, boolean fixRates)
-{ 
-  int 
-    j, 
-    count = 0, 
-    model,
-    *weightBuffer, 
-    endsite,
-    *weights, 
-    i, 
-    l;  
-
-  for(j = 0; j < tr->originalCrunchedLength; j++)
-    tr->cdta->aliaswgt[j] = 0;
-
-  for(model = 0; model < tr->NumberOfModels; ++model)
-    {
-      int
-	maxWeight = 0,
-	ctr = 0,
-	//	totalWeight = 0,
-	realNumSites = tr->origNumSitePerModel[model],	
-	*wgtVirtualAln = (int*) rax_calloc(realNumSites, sizeof(int)); 
-
-      for(j = 0; j < tr->originalCrunchedLength; ++j)
-	{
-	  if(tr->originalModel[j] == model)
-	    {
-	      wgtVirtualAln[ctr++] = tr->originalWeights[j]; 
-	      //totalWeight += tr->originalWeights[j] ; 
-	      if(maxWeight < tr->originalWeights[j])
-		maxWeight = tr->originalWeights[j]; 
-	    }
-	}
-
-      weightBuffer = (int *)rax_calloc(realNumSites, sizeof(int));
-      
-      j = 0; 
-      
-      while( j < realNumSites )
-	{
-	  int 
-	    pos = (int) (realNumSites * randum(randomSeed)); 
-	  
-	  //if((int) (totalWeight * randum(randomSeed)) < wgtVirtualAln[pos] )
-	  if((int) (maxWeight * randum(randomSeed)) < wgtVirtualAln[pos] )
-	    {
-	      weightBuffer[pos]++; 
-	      j++; 
-	    }
-	}
-
-      ctr = 0; 
-      for(j = 0; j < tr->originalCrunchedLength; ++j)
-	{
-	  if(model == tr->originalModel[j])
-	    {
-	      tr->cdta->aliaswgt[j] = weightBuffer[ctr];
-	      ctr++; 
-	    }
-	}
-
-       rax_free(weightBuffer);
-       rax_free(wgtVirtualAln);
-    }
-
-   endsite = 0;
-
-   for (j = 0; j < tr->originalCrunchedLength; j++)      
-     if(tr->cdta->aliaswgt[j] > 0)
-       endsite++; 
-
-   weights = tr->cdta->aliaswgt;
-
-   for(i = 0; i < tr->rdta->numsp; i++)
-     {     
-       unsigned char
-	 *yPos    = &(tr->rdta->y0[((size_t)tr->originalCrunchedLength) * ((size_t)i)]),
-	 *origSeq = &(tr->rdta->yBUF[((size_t)tr->originalCrunchedLength) * ((size_t)i)]);
-       int 
-	 l, 
-	 j;
-
-       for(j = 0, l = 0; j < tr->originalCrunchedLength; j++)      
-	 if(tr->cdta->aliaswgt[j] > 0)	  	    
-	   yPos[l++] = origSeq[j];	                  
-    }
-
-  for(j = 0, l = 0; j < tr->originalCrunchedLength; j++)
-    {     
-      if(weights[j])	
-	{
-	  tr->cdta->aliaswgt[l]     = tr->cdta->aliaswgt[j];
-	  tr->dataVector[l]         = tr->originalDataVector[j];
-	  tr->model[l]              = tr->originalModel[j];
-
-	  if(isRapid)
-	    {	      
-	      tr->cdta->rateCategory[l] = originalRateCategories[j];
-	      tr->invariant[l]          = originalInvariant[j];
-	    }
-	  l++;
-	}
-    }
-
-  tr->cdta->endsite = endsite;
-  fixModelIndices(tr, endsite, fixRates);
-
-  count = 0;
-  for(j = 0; j < tr->cdta->endsite; j++)
-    count += tr->cdta->aliaswgt[j];  
-
-  if(count != tr->rdta->sites)
-    printf("count=%d\ttr->rdta->sites=%d\n",count, tr->rdta->sites );
-  assert(count == tr->rdta->sites);
-}
-*/
 
   
 
@@ -496,9 +377,9 @@ void computeNextReplicate(tree *tr, int64_t *randomSeed, int *originalRateCatego
       for(j = 0; j < tr->cdta->endsite; j++)
 	count += tr->cdta->aliaswgt[j];  
       
-      if(count != tr->rdta->sites)
-	printf("count=%d\ttr->rdta->sites=%d\n",count, tr->rdta->sites );
-      assert(count == tr->rdta->sites);
+      if(count != tr->fullSites)
+	printf("count=%d\ttr->fullSites=%d\n",count, tr->fullSites);
+      assert(count == tr->fullSites);
   }
 }
 
@@ -581,9 +462,18 @@ static void copyFiles(FILE *source, FILE *destination)
     buf[1024];
   
   assert(processID == 0);
+  assert(sizeof(char) == 1);
 
-  while((c = fread(buf, sizeof(char), 1024, source)) > 0)
-    fwrite(buf, sizeof(char), c, destination);     	
+  while(!feof(source))
+    {
+      if(ferror(source) != 0)
+	assert(0);
+      
+      c = fread(buf, sizeof(char), 1024, source);
+      
+      if(c > 0)
+	fwrite(buf, sizeof(char), c, destination);        
+    }
 }
 
 static void concatenateBSFiles(int processes, char fileName[1024])
@@ -1509,18 +1399,8 @@ static void printMesquite(tree *tr, analdef *adef)
 	*f = myfopen(mesquiteTrees, "ab"),
 	*models = myfopen(mesquiteModel, "ab");
       
-      switch(tr->rateHetModel)
-	{
-	case GAMMA:
-	case GAMMA_I:
-	  Tree2String(tr->tree_string, tr, tr->start->back, TRUE, TRUE, FALSE, FALSE, TRUE, adef, SUMMARIZE_LH, FALSE, FALSE, FALSE, FALSE);
-	  break;
-	case CAT:
-	  Tree2String(tr->tree_string, tr, tr->start->back, FALSE, TRUE, FALSE, FALSE, TRUE, adef, NO_BRANCHES, FALSE, FALSE, FALSE, FALSE);
-	  break;
-	default:
-	  assert(0);
-	}
+      
+      Tree2String(tr->tree_string, tr, tr->start->back, TRUE, TRUE, FALSE, FALSE, TRUE, adef, SUMMARIZE_LH, FALSE, FALSE, FALSE, FALSE);
 	  
       fprintf(f, "%s", tr->tree_string);
 	  
@@ -1537,6 +1417,36 @@ static void printMesquite(tree *tr, analdef *adef)
     }    
 }
 
+static void printMesquiteAllTrees(tree *tr, analdef *adef)
+{
+  if(adef->mesquite)
+    {
+      FILE 
+	*f = myfopen(mesquiteMLTrees, "ab");
+            
+      Tree2String(tr->tree_string, tr, tr->start->back, TRUE, TRUE, FALSE, FALSE, TRUE, adef, SUMMARIZE_LH, FALSE, FALSE, FALSE, FALSE);
+	  
+      fprintf(f, "%s", tr->tree_string);	                    
+
+      fclose(f);           
+    }    
+}
+
+static void printMesquiteLog(analdef *adef, double l1, double l2, boolean justOneValue)
+{
+  if(adef->mesquite)
+    {
+      FILE 
+	*f = myfopen(mesquiteMLLikes, "ab");
+      
+      if(justOneValue)
+	fprintf(f, "%f\n", l1);
+      else
+	fprintf(f, "%f\t%f\n", l1, l2);
+      
+      fclose(f);
+    }
+}
 
   
 
@@ -1561,7 +1471,17 @@ void doInference(tree *tr, analdef *adef, rawdata *rdta, cruncheddata *cdta)
   char bestTreeFileName[1024]; 
   double overallTime;
 
+  double
+    *unOptLikes = (double*)rax_malloc(sizeof(double) * (size_t)adef->multipleRuns),
+    *optLikes   = (double*)rax_malloc(sizeof(double) * (size_t)adef->multipleRuns);
+
   n = adef->multipleRuns;
+
+  for(i = 0; i < n; i++)
+    {
+      unOptLikes[i] = unlikely;
+      optLikes[i] = unlikely;
+    }
      
 #ifdef _WAYNE_MPI
   if(n % processes != 0)
@@ -1623,9 +1543,14 @@ void doInference(tree *tr, analdef *adef, rawdata *rdta, cruncheddata *cdta)
                        
       computeBIGRAPID(tr, adef, TRUE);  
 
-      
+      unOptLikes[i] = tr->likelihood;    
+     
       if(tr->catOnly)
-	printMesquite(tr, adef);
+	{
+	  printMesquiteLog(adef, unOptLikes[i], 0.0, TRUE);	 	  
+	  printMesquite(tr, adef); 	 
+	  printMesquiteAllTrees(tr, adef); 		  		
+	}
 
 #ifdef _WAYNE_MPI
       if(tr->likelihood > bestLH)
@@ -1737,7 +1662,9 @@ void doInference(tree *tr, analdef *adef, rawdata *rdta, cruncheddata *cdta)
 		    }
 		  tr->treeID = i;
 		  printResult(tr, adef, TRUE);
-		  printMesquite(tr, adef);
+		  printMesquite(tr, adef);		 
+		  printMesquiteAllTrees(tr, adef); 
+		  optLikes[i] = tr->likelihood; 
 		}
 	      else
 		{
@@ -1745,17 +1672,20 @@ void doInference(tree *tr, analdef *adef, rawdata *rdta, cruncheddata *cdta)
 		    {
 		      restoreTL(rl, tr, i);
 		      evaluateGenericInitrav(tr, tr->start);
-		      printMesquite(tr, adef);
+		      printMesquite(tr, adef);	
+		      printMesquiteAllTrees(tr, adef); 
+		      optLikes[i] = tr->likelihood; 
 		    }
 		}
+	      	      
+	      printMesquiteLog(adef, unOptLikes[i], optLikes[i], FALSE);
 
-	      
 	      if(n == 1)
 		printBothOpen("Inference[%d] final GAMMA-based Likelihood: %f tree written to file %s\n", i, tr->likelihoods[i], resultFileName);	   
 	      else	    
 		printBothOpen("Inference[%d] final GAMMA-based Likelihood: %f tree written to file %s.RUN.%d\n", i, tr->likelihoods[i], resultFileName, i);
 #endif	    	 
-	    }    
+	    }	  
 	}
       else
 	{     
@@ -1830,6 +1760,8 @@ void doInference(tree *tr, analdef *adef, rawdata *rdta, cruncheddata *cdta)
 		  tr->treeID = i;
 		  printResult(tr, adef, TRUE);	
 		  printMesquite(tr, adef);
+		  printMesquiteAllTrees(tr, adef); 
+		  optLikes[i] = tr->likelihood; 
 		} 
 	      else
 		{
@@ -1837,9 +1769,13 @@ void doInference(tree *tr, analdef *adef, rawdata *rdta, cruncheddata *cdta)
 		    {
 		      restoreTL(rl, tr, i);
 		      evaluateGenericInitrav(tr, tr->start);
-		      printMesquite(tr, adef);
+		      printMesquite(tr, adef);	
+		      printMesquiteAllTrees(tr, adef); 
+		      optLikes[i] = tr->likelihood; 
 		    }
 		}
+
+	      printMesquiteLog(adef, unOptLikes[i], optLikes[i], FALSE);	    
 	      
 	      if(n == 1)	    
 		printBothOpen("Inference[%d] final GAMMA-based Likelihood: %f tree written to file %s\n", i, tr->likelihoods[i], resultFileName);
@@ -1968,13 +1904,23 @@ void doInference(tree *tr, analdef *adef, rawdata *rdta, cruncheddata *cdta)
 	  if(adef->perGeneBranchLengths && tr->NumberOfModels > 1)    
 	    printBothOpen("Per-Partition branch lengths of best-scoring ML tree written to %s.PARTITION.0 to  %s.PARTITION.%d\n\n", bestTreeFileName,  bestTreeFileName, 
 			  tr->NumberOfModels - 1);  
+
+	  if(adef->mesquite)
+	    {
+	      printBothOpen("Mesquite tree file (including best final Tree) written to:   %s\n",  mesquiteTrees);
+	      printBothOpen("Mesquite model file written to:   %s\n", mesquiteModel);
+	      printBothOpen("Initial and final log likes of trees written to: %s\n", mesquiteMLLikes);
+	    }
+	}
+      else
+	{
+	  if(adef->mesquite)
+	    printBothOpen("Initial log likes of trees written to: %s\n", mesquiteMLLikes);
 	}
 
-      if(adef->mesquite)
-	{
-	  printBothOpen("Mesquite tree file written to:   %s\n",  mesquiteTrees);
-	  printBothOpen("Mesquite model file written to:   %s\n\n", mesquiteModel);
-	}
+      if(adef->mesquite)		  	  	 
+	printBothOpen("Mesquite tree file (excluding best final Tree) written to: %s\n\n", mesquiteMLTrees);
+	
       
       printBothOpen("Overall execution time: %f secs or %f hours or %f days\n\n", overallTime, overallTime/3600.0, overallTime/86400.0);    
 #ifdef _WAYNE_MPI 
@@ -1987,6 +1933,9 @@ void doInference(tree *tr, analdef *adef, rawdata *rdta, cruncheddata *cdta)
       rax_free(rl); 
     }
   
+  rax_free(unOptLikes);
+  rax_free(optLikes);
+
 #ifdef _WAYNE_MPI
   MPI_Finalize();
 #endif
